import {Component, OnInit} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {User} from '../../models/user';
import {ApiService} from '../../services/api.service';
import {StorageService} from '../../services/storage.service';

@Component({
	selector: 'app-home',
	templateUrl: './home.component.html',
	styleUrls: ['./home.component.scss']
})
export class HomeComponent implements OnInit {

	constructor(
		private route: ActivatedRoute
	) {
	}

	ngOnInit(): void {
		if(!HomeComponent.sessionDataAvailable()) {
			this.authenticateUser();
			window.location.reload();
		}
	}

	/**
	 * Checks if there is session data saved in the local storage
	 * @return If there is session data available
	 */
	private static sessionDataAvailable(): boolean {
		let user = StorageService.getUserInfo();

		return user !== undefined;
	}

	/**
	 * Reads authentication details from query parameters and tries to authenticate the user with the API.
	 * @private
	 */
	private authenticateUser() {
		this.route.queryParams.subscribe(params => {
			let user: User = {
				firebonkId: params['firebonkId'],
				uuid: '',
				firstName: params['firstName'],
				token: params['token'],
				sessionKey: ''
			};

			if(user.firebonkId === undefined || user.firstName === undefined || user.token === undefined) {
				return;
			}

			let authenticatedUser = ApiService.performAuthentication(user);
			StorageService.setUserInfo(authenticatedUser);
		});
	}
}
